import setuptools


setuptools.setup(
    name="my_calc",
    version="0.0.1",
    author="Vadym",
    author_email="v@mail.ru",
    description="Calculator created with hillel group of 13.09.2021",
    packages=[
        '.'
    ],
    python_requires='>=3.7',
)
